==> ejc-probudget-impl-3.0.0-20220119.143053-158-sources.jar: com/ejianc/business/plan/controller/api/BudgetPlanApi.java <==
package com.ejianc.business.plan.controller.api;

import com.ejianc.business.plan.service.IBudgetPlanService;
import com.ejianc.business.plan.vo.BudgetTemVO;
import com.ejianc.business.plan.vo.RecalculateVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/budgetPlan/")
public class BudgetPlanApi {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    IBudgetPlanService budgetPlanService;

    @RequestMapping(value = "recal", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> recal(@RequestBody RecalculateVO vo) {
        return budgetPlanService.recalculate(vo, 2);
    }


    @RequestMapping(value = "getInfo", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> getInfo(@RequestBody RecalculateVO vo) {
        return budgetPlanService.getInfo(vo);
    }

    @RequestMapping(value = "getPlanNum", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> getPlanNum(@RequestBody RecalculateVO vo) {
        return budgetPlanService.getPlanNum(vo);
    }


    @RequestMapping(value = "getBudget", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BudgetTemVO> getBudget(@RequestParam("projectId") Long projectId) {
        return budgetPlanService.getBudgetVOByProjectId(projectId);
    }
}

==> ejc-probudget-impl-3.0.0-20220701.110036-217-sources.jar: com/ejianc/business/plan/controller/api/BudgetPlanApi.java <==
package com.ejianc.business.plan.controller.api;

import com.ejianc.business.plan.service.IBudgetPlanService;
import com.ejianc.business.plan.vo.BudgetTemVO;
import com.ejianc.business.plan.vo.RecalculateVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/budgetPlan/")
public class BudgetPlanApi {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    IBudgetPlanService budgetPlanService;

    @RequestMapping(value = "recal", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> recal(@RequestBody RecalculateVO vo) {
        return budgetPlanService.recalculate(vo, 2);
    }

    @RequestMapping(value = "recal3", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> recal3(@RequestParam("projectId") Long projectId) {
        RecalculateVO vo = new RecalculateVO(projectId, null);
        return budgetPlanService.recalculate(vo, 3);
    }


    @RequestMapping(value = "getInfo", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> getInfo(@RequestBody RecalculateVO vo) {
        return budgetPlanService.getInfo(vo);
    }

    @RequestMapping(value = "getPlanNum", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<RecalculateVO> getPlanNum(@RequestBody RecalculateVO vo) {
        return budgetPlanService.getPlanNum(vo);
    }


    @RequestMapping(value = "getBudget", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BudgetTemVO> getBudget(@RequestParam("projectId") Long projectId) {
        return budgetPlanService.getBudgetVOByProjectId(projectId);
    }
}
